@@ -131,8 +131,11 @@ typedef struct
 /* Length of record header */
 #define	CALMAHEADERLENGTH	4
 
-/* Label types */
-typedef enum { LABEL_TYPE_NONE, LABEL_TYPE_TEXT, LABEL_TYPE_PORT, LABEL_TYPE_CELLID } labelType;
+/* Label types
+ *  The intention is all the values can be stored/converted with unsigned char type,
+ *  C23 allows us to be explicit with the type but C99 does not, so a comment for now.
+ */
+typedef enum /* : unsigned char */ { LABEL_TYPE_NONE, LABEL_TYPE_TEXT, LABEL_TYPE_PORT, LABEL_TYPE_CELLID } labelType;
 
 /* ------------------------- Input macros ----------------------------- */
 
@@ -226,20 +229,42 @@ typedef struct portlabel
 
 /* Other commonly used globals */
 extern HashTable calmaLayerHash;
-extern int calmaElementIgnore[];
-extern CellDef *calmaFindCell();
+extern const int calmaElementIgnore[];
+extern CellDef *calmaFindCell(const char *name, bool *was_called, bool *predefined);
 
 /* (Added by Nishit, 8/18/2004--8/24/2004) */
-extern CellDef *calmaLookCell();
-extern void calmaWriteContact();
-extern CellDef *calmaGetContactCell();
+extern CellDef *calmaLookCell(char *name);
+extern void calmaWriteContacts(FILE *f);
+extern CellDef *calmaGetContactCell(TileType type, bool lookOnly);
 extern bool calmaIsContactCell;
 
-extern char *calmaRecordName();
-extern void calmaSkipSet();
-extern bool calmaParseUnits();
+extern const char *calmaRecordName(int rtype);
+extern void calmaSkipSet(const int *skipwhat);
+extern bool calmaParseUnits(void);
 
-extern int compport();
+extern int compport(const void *one, const void *two);
+
+
+#define LB_EXTERNAL	0	/* Polygon external edge	*/
+#define LB_INTERNAL	1	/* Polygon internal edge	*/
+#define LB_INIT		2	/* Data not yet valid		*/
+
+typedef struct LB1 {
+    char lb_type;		/* Boundary Type (external or internal) */
+    Point lb_start;		/* Start point */
+    struct LB1 *lb_next;	/* Next point record */
+} LinkedBoundary;
+
+typedef struct BT1 {
+    LinkedBoundary *bt_first;   /* Polygon list */
+    int bt_points;		/* Number of points in this list */
+    struct BT1 *bt_next;	/* Next polygon record */
+} BoundaryTop;
+
+extern int calmaAddSegment(LinkedBoundary **lbptr, bool poly_edge, int p1x, int p1y, int p2x, int p2y);
+extern void calmaMergeSegments(LinkedBoundary *edge, BoundaryTop **blist, int num_points);
+extern void calmaRemoveDegenerate(BoundaryTop *blist);
+extern void calmaRemoveColinear(BoundaryTop *blist);
 
 /* ------------------- Imports from CIF reading ----------------------- */
 
