@@ -104,8 +104,10 @@ typedef struct cifrstyle
 				/* Gives the Magic layer to use for labels
 				 * on each possible CIF layer.
 				 */
-    bool crs_labelSticky[MAXCIFRLAYERS];
-				/* Marker if label layer makes sticky labels */
+    /* enum labelType */ unsigned char crs_labelSticky[MAXCIFRLAYERS];
+				/* Marker if label layer makes sticky labels
+				 * enum labelType LABEL_TYPE_xxxxxx
+				 */
     CIFReadLayer *crs_layers[MAXCIFRLAYERS];
     HashTable cifCalmaToCif;    /* Table mapping from Calma layer numbers to
                                  * CIF layers
@@ -152,22 +154,45 @@ typedef struct cifpath
 
 /* Procedures */
 
-extern bool CIFParseBox(), CIFParseWire(), CIFParsePoly();
-extern bool CIFParseFlash(), CIFParseLayer(), CIFParseStart();
-extern bool CIFParseFinish(), CIFParseDelete(), CIFParseUser();
-extern bool CIFParseCall(), CIFParseTransform(), CIFParseInteger();
-extern bool CIFParsePath(), CIFParsePoint(), CIFParseSInteger();
-extern void CIFSkipToSemi(), CIFSkipSep(), CIFSkipBlanks();
-extern void CIFFreePath(), CIFCleanPath();
-extern void CIFReadCellInit(), CIFReadCellCleanup();
-extern LinkedRect *CIFPolyToRects();
-extern Transform *CIFDirectionToTrans();
-extern int CIFReadNameToType();
+extern bool CIFParseBox(void);
+extern bool CIFParseWire(void);
+extern bool CIFParsePoly(void);
+extern bool CIFParseFlash(void);
+extern bool CIFParseLayer(void);
+extern bool CIFParseStart(void);
+extern bool CIFParseFinish(void);
+extern bool CIFParseDelete(void);
+extern bool CIFParseUser(void);
+extern bool CIFParseCall(void);
+extern bool CIFParseTransform(Transform *transformp);
+extern bool CIFParseInteger(int *valuep);
+extern bool CIFParsePath(CIFPath **pathheadpp, int iscale);
+extern bool CIFParsePoint(Point *pointp, int iscale);
+extern bool CIFParseSInteger(int *valuep);
+extern void CIFSkipToSemi(void);
+extern void CIFSkipSep(void);
+extern void CIFSkipBlanks(void);
+extern void CIFFreePath(CIFPath *path);
+extern void CIFCleanPath(CIFPath *pathHead);
+extern void CIFReadCellInit(int ptrkeys);
+extern void CIFReadCellCleanup(int filetype);
+extern LinkedRect *CIFPolyToRects(CIFPath *path, Plane *plane, const PaintResultType *resultTbl,
+                                  PaintUndoInfo *ui, bool isCalma);
+extern const Transform *CIFDirectionToTrans(const Point *point);
+extern int CIFReadNameToType(char *name, bool newOK);
+
+extern int CIFCalmaLayerToCifLayer(int layer, int datatype, CIFReadStyle *calmaStyle);
+extern void CIFPropRecordPath(CellDef *def, CIFPath *pathheadp, bool iswire, char *propname);
+extern void CIFPaintWirePath(CIFPath *pathheadp, int width, bool endcap, Plane *plane,
+                             const PaintResultType *ptable, PaintUndoInfo *ui);
+extern void CIFMakeManhattanPath(CIFPath *pathHead, Plane *plane, const PaintResultType *resultTbl, PaintUndoInfo *ui);
+
+extern int CIFEdgeDirection(CIFPath *first, CIFPath *last);
 
 /* Variable argument procedures require complete prototype */
 
-extern void CIFReadError(char *format, ...);
-extern void CIFReadWarning(char *format, ...);
+extern void CIFReadError(const char *format, ...) ATTR_FORMAT_PRINTF_1;
+extern void CIFReadWarning(const char *format, ...) ATTR_FORMAT_PRINTF_1;
 
 /* Variables shared by the CIF-reading modules, see CIFreadutils.c
  * for more details:
