@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdAB.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static const char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdAB.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -70,9 +70,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
  /*ARGSUSED*/
 
 void
-CmdAddPath( w, cmd )
-    MagWindow *w;
-    TxCommand *cmd;
+CmdAddPath(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     if (cmd->tx_argc != 2) {
 	TxError("Usage: %s appended_search_path\n", cmd->tx_argv[0]);
@@ -130,11 +130,11 @@ typedef struct LA1
 #define ARRAY_DEFAULT	6
 
 void
-CmdArray(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdArray(
+    MagWindow *w,
+    TxCommand *cmd)
 {
-    static char *cmdArrayOption[] = {
+    static const char * const cmdArrayOption[] = {
 	"count 		[[xlo] xhi [ylo] yhi]	array subcells",
 	"width 		[value]			set or return array x-spacing",
 	"height 	[value]			set or return array y-spacing",
@@ -144,7 +144,7 @@ CmdArray(w, cmd)
 	NULL
     };
 
-    char **msg;
+    const char * const *msg;
     int option, locargc, argstart;
     bool doList = FALSE;
     ArrayInfo a;
@@ -156,7 +156,7 @@ CmdArray(w, cmd)
     Tcl_Obj *tobj;
 #endif
 
-    extern int selGetArrayFunc();
+    extern int selGetArrayFunc(CellUse *selUse, CellUse *use, Transform *trans, LinkedArray **arg);
 
     locargc = cmd->tx_argc;
     argstart = 1;
@@ -480,11 +480,11 @@ freelist:
  */
 
 int
-selGetArrayFunc(selUse, use, trans, arg)
-   CellUse *selUse;
-   CellUse *use;
-   Transform *trans;
-   LinkedArray **arg;
+selGetArrayFunc(
+   CellUse *selUse,
+   CellUse *use,
+   Transform *trans,
+   LinkedArray **arg)
 {
     /* Check "use" for array information and pass this to arrayInfo */
 
@@ -593,11 +593,11 @@ selGetArrayFunc(selUse, use, trans, arg)
 #define BOX_DEFAULT	13
 
 void
-CmdBox(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdBox(
+    MagWindow *w,
+    TxCommand *cmd)
 {
-    static char *cmdBoxOption[] = {
+    static const char * const cmdBoxOption[] = {
 	"width		[value]			set or return box width",
 	"height		[value]			set or return box height",
 	"size		[width height]		set or return box size",
@@ -626,7 +626,7 @@ CmdBox(w, cmd)
     bool needBox = TRUE;		/* require that box be defined */
     bool refEdit = FALSE;		/* referenced to edit cell coordinates */
     bool cursorRef = FALSE;		/* reference position is the cursor */
-    char **msg;
+    const char * const *msg;
 
     argc = cmd->tx_argc;
     if (argc > 7) goto badusage;
@@ -1155,7 +1155,7 @@ CmdBox(w, cmd)
 			boxptr->r_xbot, boxptr->r_ybot,
 			boxptr->r_xtop, boxptr->r_ytop);
 	    if (area > 0)
-		TxPrintf("  %-10lld", area);
+		TxPrintf("  %-10"DLONG_PREFIX"d", area);
 	    TxPrintf("\n");
 	    break;
 
