@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdLQ.c,v 1.9 2010/06/24 12:37:15 tim Exp $";
+static const char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdLQ.c,v 1.9 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -51,7 +51,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 
 /* Forward declarations */
 
-void CmdPaintEraseButton();
+void CmdPaintEraseButton(MagWindow *w, Point *refPoint, bool isPaint, bool isScreen);
 
 /* See the SetLabel command */
 
@@ -84,18 +84,18 @@ extern bool FileLocking;
  */
 
 void
-CmdLabelProc(text, font, size, rotate, offx, offy, pos, sticky, type)
-    char *text;			/* Text for label. */
-    int font;			/* Known font to use, or -1 for X11 fonts */
-    int size;			/* Fixed size of font (invalid with X11 fonts) */
-    int rotate;			/* Rotation (invalid with X11 fonts) */
-    int offx;			/* Position offset X (invalid with X11 fonts) */
-    int offy;			/* Position offset Y (invalid with X11 fonts) */
-    int pos;			/* Justification of text relative to text. -1
+CmdLabelProc(
+    char *text,			/* Text for label. */
+    int font,			/* Known font to use, or -1 for X11 fonts */
+    int size,			/* Fixed size of font (invalid with X11 fonts) */
+    int rotate,			/* Rotation (invalid with X11 fonts) */
+    int offx,			/* Position offset X (invalid with X11 fonts) */
+    int offy,			/* Position offset Y (invalid with X11 fonts) */
+    int pos,			/* Justification of text relative to text. -1
 				 * means "pick a nice one for me."
 				 */
-    bool sticky;		/* 1 if label should not be moved off chosen layer */
-    TileType type;		/* Type of material label is to be attached
+    bool sticky,		/* 1 if label should not be moved off chosen layer */
+    TileType type)		/* Type of material label is to be attached
 				 * to.  -1 means "pick a reasonable layer".
 				 */
 {
@@ -182,9 +182,9 @@ CmdLabelProc(text, font, size, rotate, offx, offy, pos, sticky, type)
 
 
 void
-CmdLabel(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdLabel(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     TileType type = (TileType)(-1);
     int pos = -1, font = -1, size = 0, rotate = 0, offx = 0, offy = 0;
@@ -388,9 +388,9 @@ CmdLabel(w, cmd)
  */
 
 void
-CmdLoad(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdLoad(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     int n = 1;
     int d = 1;
@@ -403,12 +403,12 @@ CmdLoad(w, cmd)
     bool failNotFound = FALSE;
     unsigned char saveVerbose;
     unsigned char flags;
-    int keepGoing();			/* forward declaration */
+    int keepGoing(CellUse *use, ClientData clientdata);			/* forward declaration */
     extern unsigned char DBVerbose;	/* from DBio.c */
 
     saveVerbose = DBVerbose;
 
-    static char *cmdLoadOption[] =
+    static const char * const cmdLoadOption[] =
     {
 	"-nowindow	load file but do not display in the layout window",
 	"-dereference	use search paths and ignore embedded cell paths in file",
@@ -550,9 +550,9 @@ CmdLoad(w, cmd)
  */
 
 int
-keepGoing(use, clientdata)
-    CellUse *use;
-    ClientData clientdata;
+keepGoing(
+    CellUse *use,
+    ClientData clientdata)
 {
     return 0;	/* keep the search going */
 }
@@ -594,13 +594,13 @@ keepGoing(use, clientdata)
  */
 
 void
-CmdLocking(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdLocking(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     int option;
 
-    static char *cmdLockingYesNo[] = { "disable", "no", "false", "off", "0",
+    static const char * const cmdLockingYesNo[] = { "disable", "no", "false", "off", "0",
 	    "enable", "yes", "true", "on", "1", 0 };
 
     if (cmd->tx_argc <= 1)
@@ -668,9 +668,9 @@ CmdLocking(w, cmd)
  */
 
 void
-CmdMove(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdMove(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     Transform t;
     Rect rootBox, newBox;
@@ -891,9 +891,9 @@ moveToPoint:
  */
 
 void
-CmdPaint(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdPaint(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     Rect editRect;
     TileTypeBitMask mask;
@@ -984,11 +984,11 @@ CmdPaint(w, cmd)
  */
 
 void
-CmdPaintEraseButton(w, refPoint, isPaint, isScreen)
-    MagWindow *w;
-    Point *refPoint;	/* Screen location at which button was raised */
-    bool isPaint;	/* True for paint, False for erase.	*/
-    bool isScreen;	/* True for screen coordinates, False for root */
+CmdPaintEraseButton(
+    MagWindow *w,
+    Point *refPoint,	/* Screen location at which button was raised */
+    bool isPaint,	/* True for paint, False for erase.	*/
+    bool isScreen)	/* True for screen coordinates, False for root */
 {
     Rect rootRect, editRect, areaReturn;
     TileTypeBitMask mask;
@@ -1085,14 +1085,14 @@ CmdPaintEraseButton(w, refPoint, isPaint, isScreen)
 #define PATHHELP	3
 
 void
-CmdPath(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdPath(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     char **pathptr;
     char *srcptr;
     int option;
-    static char *cmdPathOption[] =
+    static const char * const cmdPathOption[] =
     {
 	"search	[[+]path]	set [append to] search path",
 	"cell	[[+]path]	set [append to] cell path",
@@ -1210,9 +1210,9 @@ usage:
  */
 
 void
-CmdPolygon(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdPolygon(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     TileType type;
     int points, i, j, pNum;
@@ -1283,11 +1283,11 @@ CmdPolygon(w, cmd)
 /*----------------------------------------------------------------------*/
 
 int
-cmdPortLabelFunc1(scx, label, tpath, cdata)
-    SearchContext *scx;
-    Label *label;
-    TerminalPath *tpath;
-    ClientData cdata;
+cmdPortLabelFunc1(
+    SearchContext *scx,
+    Label *label,
+    TerminalPath *tpath,
+    ClientData cdata)
 {
     Label **rlab = (Label **)cdata;
 
@@ -1305,11 +1305,11 @@ cmdPortLabelFunc1(scx, label, tpath, cdata)
 }
 
 int
-cmdPortLabelFunc2(scx, label, tpath, cdata)
-    SearchContext *scx;
-    Label *label;
-    TerminalPath *tpath;
-    ClientData cdata;
+cmdPortLabelFunc2(
+    SearchContext *scx,
+    Label *label,
+    TerminalPath *tpath,
+    ClientData cdata)
 {
     Label **rlab = (Label **)cdata;
 
@@ -1338,11 +1338,11 @@ cmdPortLabelFunc2(scx, label, tpath, cdata)
 /*----------------------------------------------------------------------*/
 
 Label *
-portFindLabel(editDef, port, unique, nonEdit)
-    CellDef *editDef;
-    bool unique;
-    bool port;		// If TRUE, only look for labels that are ports
-    bool *nonEdit;	// TRUE if label is not in the edit cell
+portFindLabel(
+    CellDef *editDef,
+    bool port,		// If TRUE, only look for labels that are ports
+    bool unique,
+    bool *nonEdit)	// TRUE if label is not in the edit cell
 {
     int found, wrongkind;
     Label *lab, *sl;
@@ -1441,12 +1441,14 @@ portFindLabel(editDef, port, unique, nonEdit)
  */
 
 int
-complabel(const void *one, const void *two)
+complabel(
+    const void *one,
+    const void *two)
 {
     /* Natural sort order routine from DBcellname.c
      * replaces strcasecmp().
      */
-    int strcmpbynum();
+    int strcmpbynum(const char *s1, const char *s2);
 
     Label *l1 = *((Label **)one);
     Label *l2 = *((Label **)two);
@@ -1516,11 +1518,11 @@ complabel(const void *one, const void *two)
 #define PORT_HELP	15
 
 void
-CmdPort(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdPort(
+    MagWindow *w,
+    TxCommand *cmd)
 {
-    char **msg;
+    const char * const *msg;
     int argstart;
     int i, refidx, idx, pos, type, option, argc;
     unsigned int dirmask;
@@ -1530,7 +1532,7 @@ CmdPort(w, cmd)
     Rect editBox, tmpArea;
     CellDef *editDef;
 
-    static char *cmdPortOption[] =
+    static const char * const cmdPortOption[] =
     {
 	"class	[type]		get [set] port class type",
 	"use	[type]		get [set] port use type",
@@ -1551,7 +1553,7 @@ CmdPort(w, cmd)
 	NULL
     };
 
-    static char *cmdPortClassTypes[] =
+    static const char * const cmdPortClassTypes[] =
     {
 	"default",
 	"input",
@@ -1564,7 +1566,7 @@ CmdPort(w, cmd)
 	NULL
     };
 
-    static int cmdClassToBitmask[] =
+    static const int cmdClassToBitmask[] =
     {
 	PORT_CLASS_DEFAULT,
 	PORT_CLASS_INPUT,
@@ -1576,7 +1578,7 @@ CmdPort(w, cmd)
 	PORT_CLASS_FEEDTHROUGH
     };
 
-    static char *cmdPortUseTypes[] =
+    static const char * const cmdPortUseTypes[] =
     {
 	"default",
 	"analog",
@@ -1588,7 +1590,7 @@ CmdPort(w, cmd)
 	NULL
     };
 
-    static int cmdUseToBitmask[] =
+    static const int cmdUseToBitmask[] =
     {
 	PORT_USE_DEFAULT,
 	PORT_USE_ANALOG,
@@ -1599,7 +1601,7 @@ CmdPort(w, cmd)
 	PORT_USE_CLOCK
     };
 
-    static char *cmdPortShapeTypes[] =
+    static const char * const cmdPortShapeTypes[] =
     {
 	"default",
 	"abutment",
@@ -1609,7 +1611,7 @@ CmdPort(w, cmd)
 	NULL
     };
 
-    static int cmdShapeToBitmask[] =
+    static const int cmdShapeToBitmask[] =
     {
 	PORT_SHAPE_DEFAULT,
 	PORT_SHAPE_ABUT,
@@ -1873,7 +1875,7 @@ CmdPort(w, cmd)
 			{
 #ifdef MAGIC_WRAPPER
 			    Tcl_AppendResult(magicinterp, cmdPortClassTypes[idx],
-					NULL);
+					(char *)NULL);
 #else
 			    TxPrintf("Class = %s\n", cmdPortClassTypes[idx]);
 #endif
@@ -1918,7 +1920,7 @@ CmdPort(w, cmd)
 			{
 #ifdef MAGIC_WRAPPER
 			    Tcl_AppendResult(magicinterp, cmdPortUseTypes[idx],
-					NULL);
+					(char *)NULL);
 #else
 			    TxPrintf("Use = %s\n", cmdPortUseTypes[idx]);
 #endif
@@ -1963,7 +1965,7 @@ CmdPort(w, cmd)
 			{
 #ifdef MAGIC_WRAPPER
 			    Tcl_AppendResult(magicinterp, cmdPortShapeTypes[idx],
-					NULL);
+					(char *)NULL);
 #else
 			    TxPrintf("Shape = %s\n", cmdPortShapeTypes[idx]);
 #endif
@@ -2042,7 +2044,7 @@ CmdPort(w, cmd)
 		    if (pos & PORT_DIR_SOUTH) strcat(cdir, "s");
 		    if (pos & PORT_DIR_WEST) strcat(cdir, "w");
 #ifdef MAGIC_WRAPPER
-		    Tcl_AppendResult(magicinterp, cdir, NULL);
+		    Tcl_AppendResult(magicinterp, cdir, (char *)NULL);
 #else
 		    TxPrintf("Directions = %s\n", cdir);
 #endif
@@ -2074,7 +2076,7 @@ CmdPort(w, cmd)
 		{
 		    int numlabels, n, p;
 		    Label **slablist, *tlab, *lastlab;
-		    extern int complabel();
+		    extern int complabel(const void *one, const void *two);
 
 		    /* Create a sortable list of labels */
 		    numlabels = 0;
@@ -2311,10 +2313,10 @@ parsepositions:
  */
 
 void
-CmdDoProperty(def, cmd, argstart)
-    CellDef *def;
-    TxCommand *cmd;
-    int argstart;
+CmdDoProperty(
+    CellDef *def,
+    TxCommand *cmd,
+    int argstart)
 {
     int printPropertiesFunc();
     char *value;
@@ -2389,9 +2391,9 @@ CmdDoProperty(def, cmd, argstart)
  */
 
 void
-CmdProperty(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdProperty(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     CellDef *def;
 
@@ -2414,9 +2416,10 @@ CmdProperty(w, cmd)
  */
 
 int
-printPropertiesFunc(name, value)
-    char *name;
-    ClientData value;
+printPropertiesFunc(
+    const char *name,
+    ClientData value,
+    ClientData cdata) /* not used */
 {
 #ifdef MAGIC_WRAPPER
     char *keyvalue;
@@ -2466,14 +2469,15 @@ printPropertiesFunc(name, value)
 #define NLIST_TERMINAL	3
 
 void
-CmdNetlist(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdNetlist(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     int option;
-    char **msg, *lastargv;
+    const char * const *msg;
+    char *lastargv;
     Point cursor;
-    static char *cmdNetlistOption[] =
+    static const char * const cmdNetlistOption[] =
     {
 	"help           print this help information",
 	"select		select the net nearest the cursor",
@@ -2549,9 +2553,9 @@ CmdNetlist(w, cmd)
  */
 
 void
-CmdOrient(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdOrient(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     Transform trans, t2;
     int orientidx, locargc;
@@ -2560,7 +2564,7 @@ CmdOrient(w, cmd)
     CellDef *rootDef;
     bool noAdjust = FALSE;
 
-    static char *orientNames[] = {      "0", "90", "180", "270",
+    static const char * const orientNames[] = {      "0", "90", "180", "270",
                                         "v", "0v", "90v", "180v", "270v",
                                         "h", "0h", "90h", "180h", "270h",
                                         "N", "E", "S", "W",
