@@ -414,7 +414,10 @@ antennacheckVisit(dev, hc, scale, trans, editUse)
 	    if (gnode->efnode_client == (ClientData) NULL)
                 initNodeClient(gnode);
 	    if (beenVisited((nodeClient *)gnode->efnode_client, 0))
+	    {
+		freeMagic(antennaarea);
 		return 0;
+	    }
 	    else
 		markVisited((nodeClient *)gnode->efnode_client, 0);
 
@@ -872,7 +875,6 @@ antennaAccumFunc(tile, aaptr)
 	    {
 		if (type >= DBNumUserLayers)
 		{
-		    DBResidueMask(type, &sMask);
 		    for (ttype = TT_TECHDEPBASE; ttype < DBNumTypes; ttype++)
 			if (TTMaskHasType(&sMask, ttype))
 			    if (DBTypeOnPlane(ttype, plane))
@@ -983,7 +985,6 @@ antennaAccumFunc(tile, aaptr)
 
 	    if (type >= DBNumUserLayers)
 	    {
-		DBResidueMask(type, &sMask);
 		for (ttype = TT_TECHDEPBASE; ttype < DBNumTypes; ttype++)
 		    if (TTMaskHasType(&sMask, ttype))
 			if (DBTypeOnPlane(ttype, plane))
