@@ -23,6 +23,7 @@
 #define _EXTRACT_H
 
 #include "utils/magic.h"
+#include "database/database.h"  /* TileTypeBitMask */
 
 /* Extractor warnings */
 #define	EXTWARN_DUP	0x01	/* Warn if two nodes have the same name */
@@ -105,7 +106,7 @@ extern void ExtGetZAxis();
 
 extern void ExtDumpCaps();
 
-extern int extEnumTilePerim();
+extern int extEnumTilePerim(Tile *tpIn, const TileTypeBitMask *maskp, int pNum, int (*func)(), ClientData cdata);
 extern Plane *extPrepSubstrate();
 
 /* C99 compat */
