@@ -645,7 +645,7 @@ w3dHelp(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    char **msg;
+    const char * const *msg;
     W3DclientRec *crec = (W3DclientRec *) w->w_clientData;
 
     if (cmd->tx_argc == 1)
@@ -774,7 +774,7 @@ w3dSeeLayers(w, cmd)
 	if (crec->cif)
 	{
 	    /* If CIF layers, match the layer name (1 only) */
-	    if (!CIFNameToMask(cmd->tx_argv[lidx], &mask))
+	    if (!CIFNameToMask(cmd->tx_argv[lidx], &mask, NULL))
 		return;
 	}
 	else
