@@ -6,23 +6,24 @@
  * channel area, namely one that contains no embedded regions
  * where the channel's density has been exceeded.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "utils/utils.h"
@@ -31,13 +32,13 @@
 #include "debug/debug.h"
 #include "gcr/gcr.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
-#include "netlist/netlist.h"
-#include "misc/styles.h"
+#include "utils/netlist.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 
@@ -65,6 +66,8 @@ void glChanFreeMap();
 void glChanCheckCover();
 void glChanBlockDens();
 void glChanFlood();
+void glChanShowTiles();
+int glChanShowFunc();
 
 typedef struct pa
 {
@@ -74,7 +77,7 @@ typedef struct pa
 } PaintArea;
 
 PaintArea *glChanPaintList;
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -114,7 +117,7 @@ PaintArea *glChanPaintList;
  *		|HRIVER	| normal
  *		|	|
  *		+-------+
- *	
+ *
  * The reason for splitting CT_HRIVER tiles in this way (and CT_VRIVER tiles
  * vertically using similar criteria) is to ensure that there is a different
  * river tile for each channel on its opposite side.  This fact is crucial
@@ -248,7 +251,7 @@ glChanFeedFunc(tile)
     DBWFeedbackAdd(&r, mesg, EditCellUse->cu_def, 1, STYLE_OUTLINEHIGHLIGHTS);
     return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -279,7 +282,7 @@ glChanFreeMap()
     TiSetBody(newCenterTile, CHAN_BLOCKED);
     dbSetPlaneTile(glChanPlane, newCenterTile);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -360,15 +363,15 @@ glChanCheckFunc(tile, ch)
 	if (tile->ti_client != (ClientData) ch)
 	{
 	    TITORECT(tile, &r);
-	    (void) sprintf(mesg, "Tile client %x doesn't match chan %x",
-		    tile->ti_client, ch);
+	    (void) sprintf(mesg, "Tile client 0x%"DLONG_PREFIX"x doesn't match chan %p",
+		    (dlong) tile->ti_client, (void *) ch);
 	    DBWFeedbackAdd(&r, mesg, EditCellUse->cu_def,
 		    1, STYLE_MEDIUMHIGHLIGHTS);
 	}
     }
     return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -418,7 +421,7 @@ glChanClip(ch)
     {
 	char mesg[256];
 
-	(void) sprintf(mesg, "After clipping chan %x", ch);
+	(void) sprintf(mesg, "After clipping chan %p", (void *) ch);
 	glChanShowTiles(mesg);
     }
 
@@ -434,11 +437,10 @@ glChanSetClient(tile, cdata)
     return 0;
 }
 
-int
+void
 glChanShowTiles(mesg)
     char *mesg;
 {
-    int glChanShowFunc();
     char answer[100], m[1024];
 
     DBWAreaChanged(glChanDef, &TiPlaneRect, DBW_ALLWINDOWS, 0);
@@ -461,19 +463,20 @@ glChanShowFunc(tile)
 
     TITORECT(tile, &r);
     ShowRect(EditCellUse->cu_def, &r, STYLE_PALEHIGHLIGHTS);
-    (void) sprintf(mesg, "tile ch=%x type=%d",
-		tile->ti_client, TiGetType(tile));
+    (void) sprintf(mesg, "tile ch=%"DLONG_PREFIX"x type=%d",
+		(dlong) tile->ti_client, TiGetType(tile));
     TxMore(mesg);
     ShowRect(EditCellUse->cu_def, &r, STYLE_ERASEHIGHLIGHTS);
-    if (tile->ti_client == (ClientData) MINFINITY)
-	return;
+    if (tile->ti_client == (ClientData) CLIENTDEFAULT)
+	return 0;
     ch = (GCRChannel *) tile->ti_client;
     ShowRect(EditCellUse->cu_def, &ch->gcr_area, STYLE_MEDIUMHIGHLIGHTS);
-    (void) sprintf(mesg, "chan %x type=%d", ch, ch->gcr_type);
+    (void) sprintf(mesg, "chan %p type=%d", (void *) ch, ch->gcr_type);
     TxMore(mesg);
     ShowRect(EditCellUse->cu_def, &ch->gcr_area, STYLE_ERASEHIGHLIGHTS);
+    return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -536,7 +539,7 @@ glChanClipFunc(tile, area)
 
     return ret;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -619,7 +622,7 @@ glChanMergeFunc(tile)
 
     return ret;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -686,7 +689,7 @@ glChanBlockDens(ch)
 		/* Remember area of blocked tile to paint */
 		area.r_xbot = shiftedOrigin + lo * RtrGridSpacing;
 		area.r_xtop = shiftedOrigin + hi * RtrGridSpacing;
-		MALLOC(PaintArea *, pa, sizeof (PaintArea));
+		pa = (PaintArea *) mallocMagic((unsigned)(sizeof (PaintArea)));
 		pa->pa_area = area;
 		pa->pa_next = glChanPaintList;
 		pa->pa_type = CHAN_VRIVER;
@@ -715,7 +718,7 @@ glChanBlockDens(ch)
 		/* Remember area of blocked tile to paint */
 		area.r_ybot = shiftedOrigin + lo * RtrGridSpacing;
 		area.r_ytop = shiftedOrigin + hi * RtrGridSpacing;
-		MALLOC(PaintArea *, pa, sizeof (PaintArea));
+		pa = (PaintArea *) mallocMagic((unsigned)(sizeof (PaintArea)));
 		pa->pa_area = area;
 		pa->pa_next = glChanPaintList;
 		pa->pa_type = CHAN_HRIVER;
@@ -742,12 +745,12 @@ glChanBlockDens(ch)
 	{
 	    /* Clip tiles overlapped by pa->pa_area */
 	    while (DBSrPaintArea((Tile *) NULL, glChanPlane, &pa->pa_area,
-		    &DBAllTypeBits, glChanClipFunc, (ClientData) &pa->pa_area))
+		    &DBAllTypeBits, glChanClipFunc, PTR2CD(&pa->pa_area)))
 		/* Nothing */;
 
 	    /* Change the type of all tiles within the area */
 	    (void) DBSrPaintArea((Tile *) NULL, glChanPlane, &pa->pa_area,
-		    &DBAllTypeBits, glChanPaintFunc, (ClientData) pa->pa_type);
+		    &DBAllTypeBits, glChanPaintFunc, INT2CD(pa->pa_type));
 
 	    /*
 	     * Allow merging, as long as no tiles get merged across
@@ -761,7 +764,7 @@ glChanBlockDens(ch)
 	for (pa = glChanPaintList, glChanPaintList = NULL; pa; pa = pa->pa_next)
 	{
 	    glChanFlood(&pa->pa_area, pa->pa_type);
-	    FREE((char *) pa);
+	    freeMagic((char *) pa);
 	}
     } while (glChanPaintList != NULL);
 }
@@ -788,7 +791,7 @@ glChanPaintFunc(tile, type)
     TiSetBody(tile, changeTable[TiGetType(tile)][type]);
     return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -868,7 +871,7 @@ glChanFloodVFunc(tile, area)
 {
     PaintArea *pa;
 
-    MALLOC(PaintArea *, pa, sizeof (PaintArea));
+    pa = (PaintArea *) mallocMagic((unsigned) (sizeof (PaintArea)));
     pa->pa_area.r_xbot = MAX(area->r_xbot, LEFT(tile));
     pa->pa_area.r_xtop = MIN(area->r_xtop, RIGHT(tile));
     pa->pa_area.r_ybot = BOTTOM(tile);
@@ -887,7 +890,7 @@ glChanFloodHFunc(tile, area)
 {
     PaintArea *pa;
 
-    MALLOC(PaintArea *, pa, sizeof (PaintArea));
+    pa = (PaintArea *) mallocMagic((unsigned)(sizeof (PaintArea)));
     pa->pa_area.r_ybot = MAX(area->r_ybot, BOTTOM(tile));
     pa->pa_area.r_ytop = MIN(area->r_ytop, TOP(tile));
     pa->pa_area.r_xbot = LEFT(tile);
@@ -898,7 +901,7 @@ glChanFloodHFunc(tile, area)
 
     return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -978,7 +981,7 @@ glChanSplitRiver(tile)
 
     return ret;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1045,7 +1048,7 @@ glChanRiverBlock(tile)
     TiSetBody(tile, CHAN_BLOCKED);
     return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1086,7 +1089,7 @@ glChanPinToTile(hintTile, pin)
     if (TiGetType(tp) == CHAN_BLOCKED)
 	return (Tile *) NULL;
 
-    ASSERT(tp->ti_client != (ClientData) MINFINITY, "glChanPinToTile");
+    ASSERT(tp->ti_client != (ClientData) CLIENTDEFAULT, "glChanPinToTile");
     ch = (GCRChannel *) tp->ti_client;
     TITORECT(tp, &r);
     ASSERT(GEO_SURROUND(&ch->gcr_area, &r), "glChanPinToTile");
